<?php

/**
 * WebService SKYBOTConeSearch - recherche des OSS dans un champ quelconque de la sphere celeste
 *   NameSpace : http://vo.imcce.fr/webservices/skybot/
 *   Method    : skybotconesearch
 *   URI       : skybotconesearch_query.php?<param>=<valeur>[&]
 *               avec param :
 *                  -ep            -> epoque de la recherche, au format ISO ou jour julien ou date contextuelle anglosaxonne
 *                  -ra            -> ascension droite du centre du FOV, en heure sexagesimale ou decimale
 *                  -dec           -> declinaison du centre du FOV, en degre sexagesimal ou decimal
 *                  -rs, -rm, -rd  -> rayon delimitant la zone de recherche, respectivement en arcsec, arcmin, deg
 *                  -bs, -bm, -bd  -> boite RAxDEC delimitant la zone de recherche, respectivement en arcsec, arcmin, deg
 *                  -mime          -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *                  -output (-out) -> choix des parametres de sortie: 'basic', 'object' (defaut), 'obs', 'all'
 *                  -loc           -> code UAI de l'observatoire (defaut 500)
 *                  -filter        -> filtre sur l'erreur de position (arcsec)
 *                  -objFilter     -> filtre sur les objets a rechercher (asteroid,planet,comet => '000' ... '111')
 *               Alternative: jeu de parametres compatibles avec le standard ConeSearch de l'IVOA:
 *                  EPOCH          -> epoque de la recherche, au format ISO ou jour julien ou date contextuelle anglosaxonne (non standard)
 *                  RA             -> ascension droite du centre du FOV, en degre
 *                  DEC            -> ascension droite du centre du FOV, en degre
 *                  SR             -> rayon delimitant la zone de recherche, en degre
 *                  VERB           -> choix des parametres de sortie 1:'basic', 2:'object' (defaut), 3:'all'
 *               Cas special: le parametre suivant est reconnu pour la compatibilite avec Aladin:
 *                  -size          -> boite RAxDEC delimitant la zone de recherche, au format VAL ou VAL,VAL, en arcmin
 *               Parametre additionnel:
 *                  -from          -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche la liste des SSO presents dans le champ de vue a l'epoque, au format XML ou text selon le cas. 
 *               Les parametres affiches dependent de l'option '-output' :
 *                  'object': num, nom, alpha, delta, Mv
 *                  'basic' : 'object' + dRAcos(Dec), dDec, ErrPos, dgeo, dhelio, Flag
 *                  'obs'   : 'basic' + Phase, SolElong
 *                  'all'   : 'obs' + x, y, z, x', y', z', JDRef
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2013, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID 
$from = 'DemoClient';

// Input parameters
$param = array('epoch'    => 'now',
               'alpha'    => 148.67,
               'delta'    => 16.3838,
               'radius'   => '3600',
               'mime'     => "votable",
               'output'   => "basic",
               'observer' => "500",
               'filter'   => "120",
               'objFilter'=> "110");

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 0);
ini_set('default_socket_timeout', 3600);

// Namespace et WSDL du service
$namespace = 'http://vo.imcce.fr/webservices/skybot';
$uriwsdl   = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('skybotconesearch',array($param));

  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    echo "Flag  : ".$response->flag."\n";
    echo "Ticket: ".$response->ticket."\n";
    echo "Result: ";
    $res = explode(';', $response->result);
    $nbr = count($res);
    $key = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$key[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
