<?php

/**
 * WebService SKYBOTgetAsterClass - determination de la classe des asteroides dans la BDD SKyBoT 
 *   NameSpace : http://vo.imcce.fr/webservices/skybot/
 *   WSDL      : http://vo.imcce.fr/webservices/skybot/skybot.wsdl
 *   Method    : getAsterClass
 *   Request   : getAsterClass_query.php[?<param>=<valeur>]
 *               avec param :
 *                  -targets  -> liste des asteroides (sperares par une virgule) dont on veut connaitre la classe
 *                  -mime     -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *               Parametre additionnel (header):
 *                  -from     -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche les informations de classe des asteroides
 *                  Asteroid   : nom du corps
 *                  Class      : classe du corp
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2013, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID
$from = 'DemoClient';

// Input parameters
$param = array('targets' => array('ceres','pallas','vesta'),
               'mime'    => 'text');

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 0);
ini_set('default_socket_timeout', 3600);

// Namespace et WSDL du service
$namespace = 'http://vo.imcce.fr/webservices/skybot';
$uriwsdl   = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('getAsterClass', $param);
  
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
