<?php

/**
 * WebService SKYBOTAvailability - disponibilite du service SkyBoT
 *   NameSpace : http://vo.imcce.fr/webservices/skybot/
 *   Method    : getAvailability
 *   URI       : skybotstatus_query.php[?<param>=<valeur>]
 *               avec param :
 *                  -mime     -> type mime de retour de la reponse: 'votable' (defaut), 'html', 'text'
 *               Parametre additionnel:
 *                  -from     -> nom ou designation du service appelant transmis dans l'entete SOAP 
 *   Response  : Affiche les informations de statut de la BDD, avec
 *                  Availability   : statut de disponibilite
 *                  UpTime         : date depuis laquelle le service est accessible (N.A. si inconnue)
 *                  ValidTo        : date prevue d'une evenetuelle maintenance entrainant un arret du service (INF. si inconnue)
 *                  ContactDetails : informations de contact pour le service
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2013, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID 
$from = 'DemoClient';

// Input parameter
$param = array('mime'=>'text');

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 0);

// Namespace et WSDL du service
$namespace = 'http://vo.imcce.fr/webservices/skybot';
$uriwsdl   = $namespace.'/skybot.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($namespace, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('getAvailability', $param);
  
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    echo "Flag  : ".$response->flag."\n";
    echo "Ticket: ".$response->ticket."\n";
    echo "Result: ";
    $res = explode(';', $response->result);
    $nbr = count($res);
    $key = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$key[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
} 
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
